/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>
#include <widget_app.h>
#include <efl_extension.h>

#if !defined(_VIEW_H)
#define _VIEW_H

#include "main.h"


/**
 * Identifier of callbacks to be set for Widget.
 *
 * @see view_set_event_callback()
  */
typedef enum _widget_event_type {
   WIDGET_EVENT_PRESSED,   /* Touch Press Event */
   WIDGET_EVENT_RELEASED,  /* Touch Release Event */
   WIDGET_EVENT_CLICKED    /* Touch Click Event */
} widget_event_type;

/**
 * Widget event callback function signature.
 */
typedef void  (*widget_event_cb)(widget_instance_data_s *wid);

void view_create(widget_context_h context, int w, int h);
void view_alarm_widget_create(widget_context_h context, const char *file_path);
void view_set_image(Evas_Object *parent, const char *part_name, const char *image_path);
void view_set_text(Evas_Object *parent, const char *part_name, const char *text);
void view_widget_destroy(void *user_data);
void view_resize(void *user_data, int w, int h);
void view_set_event_callback(Evas_Object *parent, const char *part_name, widget_event_type event_type, void *event_cb, void *user_data);
Evas_Object *view_create_layout(Evas_Object *parent, const char *file_path, const char *group_name, Eext_Event_Cb cb_function, void *user_data);
Evas_Object *view_create_widget_win(widget_context_h context, int w, int h);
Evas_Object *view_alarm_create_layout_no_alarmlist(Evas_Object *parent, const char *file_path, const char *group_name, void *user_data);
Evas_Object *view_create_naviframe(Evas_Object *parent);
void view_set_button(Evas_Object *parent, const char *part_name, const char *style, const char *image_path, const char *text, Evas_Object_Event_Cb down_cb, Evas_Object_Event_Cb up_cb, Evas_Smart_Cb clicked_cb, void *user_data);
Elm_Object_Item* view_push_item_to_naviframe(Evas_Object *nf, Evas_Object *item, Elm_Naviframe_Item_Pop_Cb pop_cb, void *cb_data);
Evas_Object *view_create_conformant_without_indicator(Evas_Object *win);
Evas_Object *view_create_text_popup(Evas_Object *parent, double timeout, const char *text);
void view_set_smart_callback(Evas_Object *obj, char *event_type, Evas_Smart_Cb event_cb, void *user_data);
void view_send_signal_to_edje(Evas_Object *layout, const char *signal, const char *source);

#endif
