/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Elementary.h>
#include <dlog.h>
#include <bundle.h>
#include <app_preference.h>

#include "main.h"
#include "view.h"
#include "data.h"

#define BUF_LEN 1024

/**
 * @brief Initializes data that is used in this application.
 */
void data_initialize(void)
{
	/**
	 * If you need to initialize managing data,
	 * please use this function.
	 */
}

/**
 * @brief Initializes widget data that is used in this application.
 */
void data_finalize(void)
{
	/**
	 * If you need to finalize managing data,
	 * please use this function.
	 */
}

/**
 * @brief Gets path of resource.
 * @param[in] file_in File name
 * @param[in] file_path_out The point to which save full path of the resource
 * @param[in] file_path_max Size of file name include path
 */
void data_get_resource_path(const char *file_in, char *file_path_out, int file_path_max)
{
	char *res_path = app_get_resource_path();
	if (res_path) {
		snprintf(file_path_out, file_path_max, "%s%s", res_path, file_in);
		free(res_path);
	}
}

/**
 * @brief Gets the text shown on the popup.
 */
char *data_get_popup_text(void)
{
	char popup_text[1024] = { 0, };
	snprintf(popup_text, sizeof(popup_text), "%s", "You should connect to the alarm application.");

	return strdup(popup_text);
}

/**
 * @brief Gets the time of saved alarm.
 * @param[in] wid Structure has informations for managing this widget
 */
char *data_get_saved_time_text(widget_instance_data_s *wid)
{
	wid->saved_time = "2:20 PM";

	return strdup(wid->saved_time);
}
/* End of file */
